def show_form(window):
    window['UsernameFormText'].Update(visible=True)
    window['WebsiteFormName'].Update(visible=True)
    window['PasswordFormName'].Update(visible=True)
    window['EnterPasswordButton'].Update(visible=True)
    window['CancelButton'].Update(visible=True)
    window['UsernameFormInput'].Update(visible=True)
    window['WebsiteFormInput'].Update(visible=True)
    window['PasswordFormInput'].Update(visible=True)